@@ -5,7 +5,8 @@
 // this.getPanes().hide().eq(tabIndex).show();...
 
 /*global $, jQuery, OpenLayers, window, map, fillSidebar,
-setUpScreen, nothingFoundPopup, reloadGraphs, reloadMapActions,
+setUpScreen, nothingFoundPopup, reloadGraphs,
+reloadLocalizedGraphs, reloadMapActions,
 setUpTransparencySlider, setUpAnimationSlider, setUpTooltips,
 refreshLayers */
 
@@ -110,25 +111,33 @@ function show_popup(data) {
                 $("#graph-popup-content").html(data.html[0]);
             } else {
                 // Build up html with tabs.
-                html = "<ul class=\"tabs css-tabs\">";
+                html = '<ul class="tabs css-tabs">';
                 for (i = 0; i < data.html.length; i += 1) {
-                    html += "<li><a href=\"tab-" + (i + 1) + "\">Resultaat ";
-                    html += (i + 1) + "</a></li>";
+                    html += '<li><a href="#">Resultaat ';
+                    html += (i + 1) + '</a></li>';
                 }
-                html += "</ul>";
+                html += '</ul><div class="popup-panes">';
                 for (i = 0; i < data.html.length; i += 1) {
-                    html += "<div class=\"pane\"><div class=\"pane-content\">";
+                    html += '<div class="pane"><div class="pane-content">';
                     html += data.html[i];
-                    html += "</div></div>";
+                    html += '</div></div>';
                 }
+                html += '</div>';
 
                 $("#graph-popup-content").html(html);
-                $(".tabs").tabs("div.pane > div.pane-content");
-                // #graph-popup-content
+                $(".tabs").tabs("div.popup-panes > div.pane",
+                                {'effect': 'map_popup'});
             }
             overlay = $('#graph-popup').overlay();
             overlay.load();
-            reloadGraphs();
+            if (data.html.length === 1) {
+                // The tabs don't do their reload magic.
+                reloadGraphs();
+            } else {
+                // Re-reload the first one.
+                reloadLocalizedGraphs(
+                    $("div.popup-panes > div.pane")[0]);
+            }
             $(".add-snippet").snippetInteraction();
         }
         else {
@@ -399,11 +408,17 @@ jQuery.fn.lizardMapLink = function () {
 $(document).ready(function () {
     // Change "default" effect: reload graphs to fix layout.
     $.tools.tabs.addEffect(
-        "default",
+        "map_popup",
         function (tabIndex, done) {
             // hide all panes and show the one that is clicked.
 	    this.getPanes().hide().eq(tabIndex).show();
-            reloadGraphs();
             done.call();
+            if ($('#graph-popup').is(":visible")) {
+                // Don't reload the popup graph if the overlay isn't
+                // initialized yet.  There's no width then :-)
+                // It *does* reload twice when an overlay is already
+                // open, but we'll accept that for now.
+                reloadLocalizedGraphs(this.getPanes()[tabIndex]);
+            }
         });
 });
