@@ -2,6 +2,7 @@
 /*jslint browser: true */
 /*global $, OpenLayers, window, updateLayers, addProgressAnimationIntoWorkspace,
 stretchOneSidebarBox, reloadGraphs, fillSidebar, show_popup,
+alert,
 hover_popup, layers, map, refreshLayers, isCollagePopupVisible */
 
 var animationTimer, transparencyTimer;
@@ -104,11 +105,8 @@ function setUpMapLoadDefaultLocation() {
                         data.extent.bottom,
                         data.extent.right,
                         data.extent.top);
-                    // Don't decrease the zoom level here! If you want to see
-                    // a larger area in your viewport, you should define a
-                    // larger start_extent for your project. #2762
-                    zoom = map.getZoomForExtent(extent);
-                    map.setCenter(extent.getCenterLonLat(), zoom);
+                    // See #2762 and #2794.
+                    map.zoomToExtent(extent, true);
                 }
             });
     });
@@ -173,6 +171,9 @@ function setUpAddWorkspaceItem() {
         adapter_layer_json = $workspace_acceptable.attr("data-adapter-layer-json");
         url = $workspace.attr("data-url-lizard-map-workspace-item-add");
         indicateWorkspaceItemBusy($workspace_acceptable);
+        if ($(".workspace .workspace-item").length > 7) {
+            alert("Pas op, meer dan 8 workspace items zorgt voor traagheid.");
+        }
         // Request to make workspace item and update workspace.
         $.post(
             url,
@@ -265,10 +266,9 @@ function setUpWorkspaceAcceptable() {
                         (extent.west !== null))
                     {
                         ol_extent = new OpenLayers.Bounds(
-                            extent.west, extent.north,
-                            extent.east, extent.south);
-                        map.setCenter(ol_extent.getCenterLonLat(),
-                                      map.getZoomForExtent(ol_extent) - 3);
+                            extent.west, extent.south,
+                            extent.east, extent.north);
+                        map.zoomToExtent(ol_extent, true);
                     }
                 });
 		*/
@@ -573,12 +573,9 @@ function setUpWorkspaceItemPanToLayer() {
                     (extent.west !== null))
                 {
                     ol_extent = new OpenLayers.Bounds(
-                        extent.west, extent.north,
-                        extent.east, extent.south);
-                    map.setCenter(ol_extent.getCenterLonLat(),
-                                  map.getZoomForExtent(ol_extent));
-                                  // map.getZoomForExtent(ol_extent) - 3);
-                                  // ^^^ - 3 was not nice in Deltaportaal
+                        extent.west, extent.south,
+                        extent.east, extent.north);
+                    map.zoomToExtent(ol_extent, true);
                 }
             });
     });
@@ -645,6 +642,8 @@ function mapSaveLocation() {
 }
 
 
+
+
 // Initialize all workspace actions.
 $(document).ready(function () {
     setUpAddWorkspaceItem();
@@ -672,6 +671,7 @@ $(document).ready(function () {
     $("a.lizard-map-link").lizardMapLink();
 });
 
+
 // Beforeunload: this function is called just before leaving the page
 // and loading the new page. Unload however is called after loading
 // the new page.
