@@ -4,6 +4,8 @@
 /*global $, OpenLayers, popup_click_handler, popup_hover_handler, alert,
 G_PHYSICAL_MAP, G_SATELLITE_MAP, G_NORMAL_MAP, G_HYBRID_MAP, TouchHandler */
 
+// OpenLayers.ImgPath = "http://js.mapbox.com/theme/dark/";
+OpenLayers.ImgPath = "/static_media/themes/dark/";
 
 var layers, wms_layers, background_layers, map;
 layers = [];  // Used in an associative way.
@@ -46,7 +48,7 @@ function refreshBackgroundLayers() {
         layer_names = $(this).attr("data-layer-layer-names");
         data_google_type = $(this).attr("data-google-layer-type");
         identifier = url + layer_names + data_google_type;
-        if (background_layers.indexOf(identifier) === -1) {
+        if ($.inArray(identifier, background_layers) === -1) {
             // Not already present, adding it.
             if (layer_type === "GOOGLE")
             {
@@ -64,20 +66,25 @@ function refreshBackgroundLayers() {
                 }
                 base_layer = new OpenLayers.Layer.Google(
                     layer_name,
-                    {type: google_type, sphericalMercator: true});
+                    {type: google_type,
+                     transitionEffect: 'resize',
+                     sphericalMercator: true});
             }
             else if (layer_type === "OSM")
             {
                 base_layer = new OpenLayers.Layer.OSM(
-                    layer_name, url, {buffer: 0});
+                    layer_name, url,
+                    {buffer: 0,
+                     transitionEffect: 'resize'});
             }
             else if (layer_type === "WMS")
             {
                 base_layer = new OpenLayers.Layer.WMS(
                     layer_name, wms_url,
-                    {'layers': layer_names, 'format': 'image/png',
+                    {'layers': layer_names,
+                     'format': 'image/png',
                      'maxResolution': 364},
-                    {'isBaseLayer': true, 'buffer': 1}
+                    {'isBaseLayer': true, transitionEffect: 'resize', 'buffer': 1}
                 );
             }
             // layers.base_layer
@@ -113,6 +120,7 @@ function refreshWorkspaceLayers() {
                 workspace_wms,
                 {layers: 'basic'},
                 {singleTile: true,
+                 transitionEffect: 'resize',
                  isBaseLayer: false});
             layers[workspace_id].mergeNewParams({'random': Math.random()});
             map.addLayer(layers[workspace_id]);
@@ -148,7 +156,7 @@ function refreshWmsLayers() {
     });
     // Remove unused ones.
     $.each(wms_layers, function (key, value) {
-        if (ids_found.indexOf(key) === -1) {
+        if ($.inArray(key, ids_found) === -1) {
             // Remove now-unused layer.
             map.removeLayer(value);
             delete wms_layers[key];
@@ -222,16 +230,16 @@ function showMap() {
     start_extent_right = $lizard_map_wms.attr("data-start-extent-right");
     start_extent_bottom = $lizard_map_wms.attr("data-start-extent-bottom");
     start_extent = new OpenLayers.Bounds(
-        parseFloat(start_extent_left), parseFloat(start_extent_top),
-        parseFloat(start_extent_right), parseFloat(start_extent_bottom));
+        parseFloat(start_extent_left), parseFloat(start_extent_bottom),
+        parseFloat(start_extent_right), parseFloat(start_extent_top));
 
     max_extent_left = $lizard_map_wms.attr("data-max-extent-left");
     max_extent_top = $lizard_map_wms.attr("data-max-extent-top");
     max_extent_right = $lizard_map_wms.attr("data-max-extent-right");
     max_extent_bottom = $lizard_map_wms.attr("data-max-extent-bottom");
     max_extent = new OpenLayers.Bounds(
-        parseFloat(max_extent_left), parseFloat(max_extent_top),
-        parseFloat(max_extent_right), parseFloat(max_extent_bottom));
+        parseFloat(max_extent_left), parseFloat(max_extent_bottom),
+        parseFloat(max_extent_right), parseFloat(max_extent_top));
 
     // Set up projection and bounds.
     if (projection === "EPSG:900913")
@@ -354,10 +362,67 @@ function showMap() {
 
     // Zoom to startpoint. Important to parse numbers, else a bug in
     // OpenLayers will initially prevent "+" from working.
-    map.setCenter(start_extent.getCenterLonLat(),
-                  map.getZoomForExtent(start_extent));
+    //
+    // Saving and subsequently restoring a start_extent often results in a
+    // zoom level that is decreased by -1. This might be due to rounding
+    // errors. By passing true to zoomToExtent, we will get the zoom
+    // level that most closely fits the specified bounds.
+    // See #2762 and #2794.
+    map.zoomToExtent(start_extent, true);
 
 }
 
 
-$(document).ready(showMap);
+/*
+Creates parameters part of url
+*/
+function getMapUrl() {
+    var extent, srs, activelayers, url, width, height, i;
+    extent  = map.getExtent();
+    extent  = [extent.left, extent.bottom,
+               extent.right, extent.top].join(',');
+    srs = map.getProjectionObject();
+    activelayers = [];
+    url = "?";
+    width   = map.getSize().w;
+    height  = map.getSize().h;
+
+    for (i = map.layers.length - 1; i >= 0; i -= 1) {
+        if (!map.layers[i].getVisibility()) {
+            continue;
+        }
+        if (!map.layers[i].calculateInRange()) {
+            continue;
+        }
+        activelayers[activelayers.length] = map.layers[i].params.LAYERS;
+    }
+
+    activelayers = activelayers.join(',');
+
+    url += "LAYERS=" + activelayers;
+    url += "&SRS=" + srs;
+    url += "&BBOX=" + extent;
+    url += "&WIDTH=" + width;
+    url += "&HEIGHT=" + height;
+
+    return url;
+}
+
+/*
+Replaces a href attr. of 'Download' subelement
+*/
+function setDownloadImageLink() {
+    $('span#download').click(function (e) {
+        var url = "/map/download/";
+        url = url + getMapUrl();
+        $(this).find("a").attr({
+            href: url
+        });
+    });
+}
+
+
+$(document).ready(function () {
+    showMap();
+    setDownloadImageLink();
+});
